@@ -1,12 +1,12 @@
-: magical incantation finds Perl as long as it's in the user's path
+#!/usr/bin/perl
 eval 'exec perl -wS $0 ${1+"$@"}'
 	if 0;
 
 ############################################################################
 # Please change this accordingly if you change the DESTDIR in the tarball 
 # distribution Makefile or the --prefix of the RPM installation
-$LIBDIR = "/usr/local/lib/igal2";
-# for example if you make DESTDIR=/usr then $LIBDIR="/usr/lib/igal2"
+$IGALDIR = "/usr/local/share/igal2";
+# for example if you make DESTDIR=/usr then $IGALDIR="/usr/share/igal2"
 ############################################################################
 #
 # A short note from Eric Pop the developer of the "old" igal version:
@@ -34,9 +34,14 @@ $HAVEIM = 0;
 $HAVELJ = 0;
 ############################################################################
 
-# This is IGAL version 2.2, an online Image GALlery generator.
-#   Copyright (C) 2000 Eric Pop, 2003 Wolfgang Trexler
-#   This version was enhanced by Wolfgang Trexler (wt) Apr. 2003 - May 2016
+# This is IGAL version 2.3, an online Image GALlery generator.
+#   Copyright (C)
+#   	2000 Eric Pop,
+#   	2003 Wolfgang Trexler,
+#   	2019 Johnny A. Solbu
+#   This version was enhanced by:
+#   	Wolfgang Trexler (wt) Apr. 2003 - May 2016
+#   	Johnny A. Solbu 2019
 #
 #   This program is free software; you can redistribute it and/or modify
 #   it under the terms of the GNU General Public License as published by
@@ -56,6 +61,7 @@ $HAVELJ = 0;
 # Email: epop@stanford.edu
 # Enhancements were done by: Wolfgang Trexler, Alexander Zangerl
 # EMail: wt-igal@trexler.at
+# Project manager: Johnny A. Solbu <johnny@solbu.net>
 
 use FileHandle;
 use Getopt::Long;
@@ -65,7 +71,7 @@ $ExifTool = eval "use Image::ExifTool; 1" ? 1 : 0;
 
 
 # some constants
-$VERSION = "2.2";
+$VERSION = "2.3";
 $Getopt::Long::ignorecase = 0;
 $itile = "tile.png";
 $slidetemplate = "slidetemplate2.html";
@@ -112,7 +118,7 @@ $opt_AddSubdir = "0";  # Add subdirectories to index.html file
 $opt_pagination = "0"; # maximum number of images on one page, zero means no pagination
 
 $usage = <<"END_OF_USAGE";
-This is iGal2 $VERSION an HTML image slide show generator.
+This is iGal2 v$VERSION an HTML image slide show generator.
 Syntax:  igal [-option -option ...]
 Options:     -a           write image sizes under thumbnails on index page
              -c           first generate and then use captions
@@ -166,12 +172,13 @@ Options:     -a           write image sizes under thumbnails on index page
                           of parameter -w (default 5).
                           Default 0 - means no pagination at all.
 Note:         default values are given in parentheses (where applicable).
-Authors:      Wolfgang Trexler <wt-igal\@trexler.at>
+Authors:      Johnny A. Solbu <johnny\@solbu.net>
+              Wolfgang Trexler <wt-igal\@trexler.at>
               Eric Pop <epop\@stanford.edu> (original igal)
 	      contributions: 
               Stewart Addison <contactsxa\@gmail.com>, Riku Kalinen,
               Alexander Zangerl
-URL:          http://igal.trexler.at/
+URL:          https://github.com/solbu/igal2
 END_OF_USAGE
 
 # store command-line options upfront to write in the index <HEAD>
@@ -205,8 +212,8 @@ die "Critical failure: Lib Image::ExifTool not install but EXIF Tags (option -e)
 $opt_d =~ s/\/$//;
 
 # let users store their templates in a $HOME/.igal directory, if it exists,
-# instead of the site-wide /usr/local/lib/igal (from line 8 up top)
-$LIBDIR = $userigaldir if ((-r $userigaldir) && (-d $userigaldir));
+# instead of the site-wide /usr/lib/igal (from line 8 up top)
+$IGALDIR = $userigaldir if ((-r $userigaldir) && (-d $userigaldir));
 
 # load up image files from $opt_d into array @imgfiles
 opendir DIR, $opt_d or die "Can't open directory $opt_d\n";
@@ -477,10 +484,10 @@ if ( $opt_m ) {
 if ($opt_s) {
 	print "Linking thumbnails directly to image files...  Making no html slides.\n";
 	if (! -e "$opt_d/$opt_dest$csstemplate") {
-		print "No CSS template file ... getting $LIBDIR/$csstemplate\n";
-		die "$LIBDIR cannot be read or does not exist.\nPlease install igal properly.\n" unless (-r $LIBDIR);
-		die "$LIBDIR/$csstemplate cannot be read or does not exist.\nPlease install igal properly.\n" unless (-r "$LIBDIR/$csstemplate");
-		system("cp -f $LIBDIR/$csstemplate \"$opt_d/$opt_dest\"");
+		print "No CSS template file ... getting $IGALDIR/$csstemplate\n";
+		die "$IGALDIR cannot be read or does not exist.\nPlease install igal properly.\n" unless (-r $IGALDIR);
+		die "$IGALDIR/$csstemplate cannot be read or does not exist.\nPlease install igal properly.\n" unless (-r "$IGALDIR/$csstemplate");
+		system("cp -f $IGALDIR/$csstemplate \"$opt_d/$opt_dest\"");
         }
 } else {
 	$nfiles = @imgfiles;      # total number of files (same as # of captions)
@@ -498,18 +505,18 @@ if ($opt_s) {
 	}
 	system("rm -f \"$opt_d/$opt_dest*.html\"");
 	if (! -e "$opt_d/$opt_dest$csstemplate") {
-		print "No CSS template file ... getting $LIBDIR/$csstemplate\n";
-		die "$LIBDIR cannot be read or does not exist.\nPlease install igal properly.\n" unless (-r $LIBDIR);
-		die "$LIBDIR/$csstemplate cannot be read or does not exist.\nPlease install igal properly.\n" unless (-r "$LIBDIR/$csstemplate");
-		system("cp -f $LIBDIR/$csstemplate \"$opt_d/$opt_dest\"");
+		print "No CSS template file ... getting $IGALDIR/$csstemplate\n";
+		die "$IGALDIR cannot be read or does not exist.\nPlease install igal properly.\n" unless (-r $IGALDIR);
+		die "$IGALDIR/$csstemplate cannot be read or does not exist.\nPlease install igal properly.\n" unless (-r "$IGALDIR/$csstemplate");
+		system("cp -f $IGALDIR/$csstemplate \"$opt_d/$opt_dest\"");
 	} else {
 		print "Found CSS template file $opt_dest$csstemplate ... using it.\n";
 	}
 	if (! -e "$opt_d/$opt_dest.$slidetemplate") {
-		print "No $opt_dest.$slidetemplate file ... getting a copy from $LIBDIR/\n";
-		die "$LIBDIR cannot be read or does not exist.\nPlease install igal properly.\n" unless (-r $LIBDIR);
-		die "$LIBDIR/$slidetemplate cannot be read or does not exist.\nPlease install igal properly.\n" unless (-r "$LIBDIR/$slidetemplate");
-		system("cp -f $LIBDIR/$slidetemplate \"$opt_d/$opt_dest.$slidetemplate\"");
+		print "No $opt_dest.$slidetemplate file ... getting a copy from $IGALDIR/\n";
+		die "$IGALDIR cannot be read or does not exist.\nPlease install igal properly.\n" unless (-r $IGALDIR);
+		die "$IGALDIR/$slidetemplate cannot be read or does not exist.\nPlease install igal properly.\n" unless (-r "$IGALDIR/$slidetemplate");
+		system("cp -f $IGALDIR/$slidetemplate \"$opt_d/$opt_dest.$slidetemplate\"");
 	} else {
 		print "Found $opt_dest.$slidetemplate file ... using it.\n";
 	}
@@ -617,10 +624,10 @@ if ($opt_s) {
 if ($opt_r) {
 	print "Got option -r... omitting film reel effect.\n";
 } elsif (! -e "$opt_d/$opt_dest.$itile") {
-	print "No $opt_dest.$itile file... getting a copy from $LIBDIR/\n";
-	die "$LIBDIR cannot be read or does not exist.\nPlease install igal properly.\n" unless (-r $LIBDIR);
-	die "$LIBDIR/$itile cannot be read or does not exist.\nPlease install igal properly.\n" unless (-r "$LIBDIR/$itile");
-	system("cp -f $LIBDIR/$itile \"$opt_d/$opt_dest.$itile\"");
+	print "No $opt_dest.$itile file... getting a copy from $IGALDIR/\n";
+	die "$IGALDIR cannot be read or does not exist.\nPlease install igal properly.\n" unless (-r $IGALDIR);
+	die "$IGALDIR/$itile cannot be read or does not exist.\nPlease install igal properly.\n" unless (-r "$IGALDIR/$itile");
+	system("cp -f $IGALDIR/$itile \"$opt_d/$opt_dest.$itile\"");
 } else {
 	print "Found $opt_dest.$itile file ... using it.\n";
 }
@@ -632,10 +639,10 @@ if (($HAVEIM) and (! $opt_r)) {
 }
 
 if (! -e "$opt_d/$opt_dest.$indextemplate") {
-	print "No $opt_dest.$indextemplate file... getting a copy from $LIBDIR/\n";
-	die "$LIBDIR cannot be read or does not exist.\nPlease install igal properly.\n" unless (-r $LIBDIR);
-	die "$LIBDIR/$indextemplate cannot be read or does not exist.\nPlease install igal properly.\n" unless (-r "$LIBDIR/$indextemplate");
-	system("cp -f $LIBDIR/$indextemplate \"$opt_d/$opt_dest.$indextemplate\"");
+	print "No $opt_dest.$indextemplate file... getting a copy from $IGALDIR/\n";
+	die "$IGALDIR cannot be read or does not exist.\nPlease install igal properly.\n" unless (-r $IGALDIR);
+	die "$IGALDIR/$indextemplate cannot be read or does not exist.\nPlease install igal properly.\n" unless (-r "$IGALDIR/$indextemplate");
+	system("cp -f $IGALDIR/$indextemplate \"$opt_d/$opt_dest.$indextemplate\"");
 } else {
 	print "Found $opt_dest.$indextemplate ... using it.\n";
 }
@@ -649,10 +656,10 @@ $indexfile =~ s/<!--#IGAL-CSS#-->/$opt_dest$csstemplate/g; # set the name (and p
 if ($opt_AddSubdir && @directories) {
 
 	if (! -e "$opt_d/$opt_dest.$directorylinefile") {
-		print "No $opt_dest.$directorylinefile file ... getting a copy from $LIBDIR/\n";
-		die "$LIBDIR cannot be read or does not exist.\nPlease install igal properly.\n" unless (-r $LIBDIR);
-		die "$LIBDIR/$directorylinefile cannot be read or does not exist.\nPlease install igal properly.\n" unless (-r "$LIBDIR/$directorylinefile");
-		system("cp -f $LIBDIR/$directorylinefile \"$opt_d/$opt_dest.$directorylinefile\"");
+		print "No $opt_dest.$directorylinefile file ... getting a copy from $IGALDIR/\n";
+		die "$IGALDIR cannot be read or does not exist.\nPlease install igal properly.\n" unless (-r $IGALDIR);
+		die "$IGALDIR/$directorylinefile cannot be read or does not exist.\nPlease install igal properly.\n" unless (-r "$IGALDIR/$directorylinefile");
+		system("cp -f $IGALDIR/$directorylinefile \"$opt_d/$opt_dest.$directorylinefile\"");
 	} else {
 		print "Found $opt_dest.$directorylinefile file ... using it.\n";
 	}
